==> nextcloud-23.0.12p1.tgz: nextcloud/apps/dashboard/l10n/hu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Irányítópult",
    "Dashboard app" : "Irányítópult alkalmazás",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Kezdje informáltan a napot\n\nA Nextcloud irányítópult a napja kezdőpontja, áttekintést nyújtva a közelgő találkozókról, sürgős levelekről, csevegőüzenetekről, hibajegyekről, a legfrissebb tweetekről és sok másról. A felhasználók modulokat adhatnak hozzá, és tetszés szerint változtathatják a hátteret.",
    "Customize" : "Testreszabás",
    "Edit widgets" : "Modulok szerkesztése",
    "Get more widgets from the App Store" : "További modulok letöltése az alkalmazástárból.",
    "Weather service" : "Időjárás szolgáltatás",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Az adatvédelem érdekében az információt a Nextcloud kiszolgáló kéri le az Ön nevében, így az Ön személyes adatai nem kerülnek az időjárási adatok szolgáltatójához.",
    "Weather data from Met.no" : "Időjárási adatok a Met.no-tól",
    "geocoding with Nominatim" : "geokódolás a Nominatimmal",
    "elevation data from OpenTopoData" : "magassági adatok az OpenTopoDatától",
    "Weather" : "Időjárás",
    "Status" : "Állapot",
    "Good morning" : "Jó reggelt",
    "Good morning, {name}" : "Jó reggelt, {name}",
    "Good afternoon" : "Jó napot",
    "Good afternoon, {name}" : "Jó napot, {name}",
    "Good evening" : "Jó estét",
    "Good evening, {name}" : "Jó estét, {name}",
    "Hello" : "Üdv",
    "Hello, {name}" : "Üdv {name}!",
    "Show something" : "Mutasson valamit",
    "Change background image" : "Háttérkép megváltoztatása",
    "Pick from Files" : "Választás a fájlok közül",
    "Default images" : "Alapértelmezett képek",
    "Plain background" : "Egyszerű háttér",
    "Insert from {productName}" : "Beillesztés innen: {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/dashboard/l10n/hu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Irányítópult",
    "Dashboard app" : "Irányítópult alkalmazás",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Kezdje informáltan a napot\n\nA Nextcloud irányítópult a napja kezdőpontja, áttekintést nyújtva a közelgő találkozókról, sürgős levelekről, csevegőüzenetekről, hibajegyekről, a legfrissebb tweetekről és sok másról. A felhasználók modulokat adhatnak hozzá, és tetszés szerint változtathatják a hátteret.",
    "Customize" : "Testreszabás",
    "Edit widgets" : "Modulok szerkesztése",
    "Get more widgets from the App Store" : "További modulok letöltése az alkalmazástárból.",
    "Change background image" : "Háttérkép megváltoztatása",
    "Weather service" : "Időjárás szolgáltatás",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Az adatvédelem érdekében az információt a Nextcloud kiszolgáló kéri le az Ön nevében, így az Ön személyes adatai nem kerülnek az időjárási adatok szolgáltatójához.",
    "Weather data from Met.no" : "Időjárási adatok a Met.no-tól",
    "geocoding with Nominatim" : "geokódolás a Nominatimmal",
    "elevation data from OpenTopoData" : "magassági adatok az OpenTopoDatától",
    "Weather" : "Időjárás",
    "Status" : "Állapot",
    "Good morning" : "Jó reggelt",
    "Good morning, {name}" : "Jó reggelt, {name}",
    "Good afternoon" : "Jó napot",
    "Good afternoon, {name}" : "Jó napot, {name}",
    "Good evening" : "Jó estét",
    "Good evening, {name}" : "Jó estét, {name}",
    "Hello" : "Üdv",
    "Hello, {name}" : "Üdv {name}!",
    "Pick from Files" : "Választás a fájlok közül",
    "Default image" : "Alapértelmezett kép",
    "Plain background" : "Egyszerű háttér",
    "Insert from {productName}" : "Beillesztés innen: {productName}-",
    "Show something" : "Mutasson valamit",
    "Default images" : "Alapértelmezett képek"
},
"nplurals=2; plural=(n != 1);");
